@@ -8,7 +8,7 @@ import re
 from bson.objectid import ObjectId
 
 from disco import Job, upload_file, input_files_from_bucket, Cluster
-from disco.core.constants import JobStatus
+from disco.core.constants import JobStatus, InstanceCost
 from disco.core.exceptions import DiscoException, TimeOutError, GraphQLRequestException, \
     BucketPathsException, BucketPathsErrorTypes, RequestException
 from disco.models import JobDetails
@@ -51,7 +51,7 @@ def job_commands():
 @click.option('-cic', '--instance-cost', help="The cost type of an instance, available only on clouds.\n"
                                               "1.'guaranteed': Aws - On Demand, Gcp - VM, Azure - Virtual Machines, Packet - On Demand.\n"
                                               "2.'lowCost': only supported on aws cloud, uses aws spot instances and reduces costs.",
-                                              type=click.Choice(['guaranteed', 'lowCost']))
+                                              type=click.Choice([InstanceCost.guaranteed.value, InstanceCost.lowCost.value]))
 @click.option('-rep', '--repository-id', help='ID of the repository in which the script file resides.')
 @click.option('-f', '--file-path', 'script_file_path_in_repo', help='Path in the Git repository to the script file.')
 @click.option('-did', '--docker-image-id', help='The id of the docker image to run the job in')  # pylint: disable=all
