@@ -11,6 +11,7 @@ from azure.storage.blob import BlobClient
 from disco.core import create_progress_bar, constants
 from disco.core.constants import ClusterType
 from .base_controller import BaseController
+from .gql.request_mixin import _RequestsMixin
 
 
 class FileWrapper:
@@ -44,6 +45,7 @@ class Asset(BaseController):
                          )
 
     @classmethod
+    @_RequestsMixin.handle_500_errors
     def _upload_to_aws_with_callback(cls, url, file_name, form_fields, file_content_bytes, callback):
         """
         Upload file to AWS S3 with callback for monitoring the progress
@@ -82,6 +84,7 @@ class Asset(BaseController):
         blob_client.upload_blob(file_content_bytes)
 
     @classmethod
+    @_RequestsMixin.handle_500_errors
     def _upload_to_gcp_with_callback(cls, url, file_content_bytes, callback):
         """
         Upload file to GCP with callback for monitoring the progress
