@@ -49,3 +49,8 @@ class ClusterType(enum.Enum):
     GCP = 'gcp'
     Packet = 'packet'
     OnPremise = 'onPremise'
+
+class InstanceCost(enum.Enum):
+    """Instance cost types"""
+    lowCost = 'lowCost'
+    guaranteed = 'guaranteed'
