@@ -12,6 +12,7 @@ from typing import Union
 from disco.core.config import Config
 from .models import JobDetails, Task
 from .asset import Asset
+from .cluster import Cluster
 from .core import constants, exceptions, \
     is_venv, zip_tools
 from .task import TaskResult
@@ -87,11 +88,18 @@ class Job(BaseController):
         Returns:
             ID of requirements file in the DB
         """
+        if cluster_id:
+            cluster = Cluster.fetch_and_validate_by_id(cluster_id)
+            if not cluster:
+                raise exceptions.DiscoException(f'Cluster {cluster_id} is invalid')
+        else:
+            cluster = None
+
         requirements = cls.generate_requirements()
         req_file_id = Asset().upload(
             'requirements.txt',
             requirements,
-            cluster_id,
+            cluster,
             show_progress_bar=False)
         return req_file_id
 
