@@ -36,7 +36,8 @@ class Task(BaseModel):
         Returns:
             str
         """
-        return self._data.get('request', {}).get('inputFile', {}).get('id')
+        input_file = self._data.get('request', {}).get('inputFile', {})
+        return input_file.get('id') if input_file is not None and 'id' in input_file else None
 
     @property
     def input_file_name(self):
@@ -44,7 +45,8 @@ class Task(BaseModel):
         Returns:
             str
         """
-        return self._data.get('request', {}).get('inputFile', {}).get('name')
+        input_file = self._data.get('request', {}).get('inputFile', {})
+        return input_file.get('name') if input_file is not None and 'name' in input_file else None
 
     @property
     def artifact_ids(self):
