@@ -9,7 +9,7 @@ import dill
 from . import job_file_handler
 import os
 from disco import Job
-from disco.core.constants import JobStatus
+from disco.core.constants import JobStatus, InstanceCost
 
 
 def add_job(job_name, func, args, args_types, wait=False):
@@ -39,6 +39,7 @@ def get_results(job):
 
 def add_job_request(job_name, script_module_and_req_ids, input_files_ids, wait=False):
     machine_size = os.environ.get('DISCO_MACHINE_SIZE')
+    instance_cost_type = os.environ.get('DISCO_INSTANCE_COST')
     cluster_id = os.environ.get('DISCO_CLUSTER_ID')
     job = Job.create(script_file_id=script_module_and_req_ids[0],
                      input_file_ids=input_files_ids,
@@ -46,6 +47,7 @@ def add_job_request(job_name, script_module_and_req_ids, input_files_ids, wait=F
                      job_name=job_name,
                      cluster_id=cluster_id,
                      cluster_instance_type=machine_size if machine_size is not None else 's',
+                     instance_cost=instance_cost_type if instance_cost_type is not None else InstanceCost.guaranteed.value,
                      upload_requirements_file=False)
     if wait:
         job.start()
