@@ -7,7 +7,7 @@ import shutil
 from disco.models import ClusterDetails
 from disco import Job
 from disco.core.exceptions import BucketPathsException, BucketPathsErrorTypes, RequestException, GraphQLRequestException
-from disco.core.constants import JobStatus, ClusterType
+from disco.core.constants import JobStatus, ClusterType, InstanceCost
 from disco.task import TaskResult
 from .sdk_mocks import MockListJobsResponse, MockViewJobResponse, MockBadIdException, \
     MockViewStoppedJobResponse, MockListTasksResponse, MockListTasksResponseNoInputFile
@@ -1130,7 +1130,7 @@ class TestJobCommands(BaseTest):
                 assert output_message_includes(result, 'Created job with id job_id')
                 job_create_mock.assert_called_with(script_file_id='file_id', input_file_ids=[],
                                                    constants_file_ids=[], job_name='job_name',
-                                                   cluster_instance_type='s', cluster_id=None, instance_cost='lowCost' ,
+                                                   cluster_instance_type='s', cluster_id=None, instance_cost=InstanceCost.lowCost.value,
                                                    script_repo_id=None, script_file_path_in_repo=None, auto_start= True,
                                                    upload_requirements_file=True, docker_image_id=None)
 
