@@ -13,6 +13,7 @@ import dill
 import time
 from disco import asset, Job
 import requests
+from disco.core.constants import InstanceCost
 SCRIPT_PICKLE_RESULT = """
 with open('run-result/result.pickle', 'wb') as f_result:
     dill.dump(result, f_result)   
@@ -66,7 +67,7 @@ def disco_job(func, name_of_job=None, *args, **kwargs):
     # TODO: Enable a client to specify a cluster ID
     script_file_id = asset.upload_file(str(job_name) + '.py', script, show_progress_bar=False)
     input_file_id = asset.upload_file(str(job_name) + 'input.pickle', input_file, show_progress_bar=False)
-    job = Job.create(script_file_id, [input_file_id], [], job_name)
+    job = Job.create(script_file_id, [input_file_id], [], job_name, instance_cost=InstanceCost.lowCost.value)
     job.start()
     task_result = job.get_results(block=True)
     if task_result:
