@@ -18,7 +18,7 @@ from disco.core.constants import JobStatus
 from tests.base_test import BaseTest
 from tests.live import env
 from .env import LIVE_TESTS_TIMEOUT_SECONDS
-
+from disco.core.constants import InstanceCost
 
 @pytest.mark.skipif(env.skip, reason=env.reason)
 class TestTasksLive(BaseTest):
@@ -46,7 +46,7 @@ class TestTasksLive(BaseTest):
         ''')
         script_file_id = disco.upload_file('woof.py', task_content)
 
-        job = disco.Job.create(script_file_id)
+        job = disco.Job.create(instance_cost=InstanceCost.lowCost.value, script_file_id=script_file_id)
         job.start()
 
         print(f'Waiting for job {job.job_id} to finish...')
@@ -124,7 +124,8 @@ class TestTasksLive(BaseTest):
 
         job = disco.Job.create(
             script_file_id,
-            input_file_ids=input_file_ids
+            input_file_ids=input_file_ids,
+            instance_cost=InstanceCost.lowCost.value
         )
 
         job.start()
@@ -167,7 +168,7 @@ class TestTasksLive(BaseTest):
 
         # Ensure we use the correct python path when doing `pip freeze` to get the venv requirements
         with mock.patch('sys.executable', venv_python_path):
-            job = disco.Job.create(script_file_id)
+            job = disco.Job.create(script_file_id, instance_cost=InstanceCost.lowCost.value)
 
         job.start()
 
@@ -197,7 +198,7 @@ class TestTasksLive(BaseTest):
 
         script_file_id = disco.upload_file('meow.py', task_content)
 
-        job = disco.Job.create(script_file_id)
+        job = disco.Job.create(script_file_id, instance_cost=InstanceCost.lowCost.value)
 
         print(f'Waiting for tasks of job {job.job_id}')
 
