@@ -11,9 +11,9 @@ import pytest
 
 import disco
 from disco.core import constants as const, exceptions
-from disco.models import JobDetails
+from disco.models import JobDetails, ClusterDetails
 from .base_test import BaseTest
-
+from disco.core.constants import InstanceCost
 
 class TestJobs(BaseTest):
 
@@ -172,19 +172,23 @@ class TestJobs(BaseTest):
 
     @BaseTest.with_config_and_env()
     @mock.patch('disco.job.is_venv', return_value=True)
-    def test__get_venv_requirements(self, _is_venv):
+    @mock.patch('disco.Cluster.fetch_and_validate_by_id')
+    def test__get_venv_requirements(self, cluster_fetch_and_validate_by_id, _is_venv):
         with mock.patch('subprocess.Popen') as _popen, \
                 mock.patch('disco.asset.Asset.upload') as _upload:
             res = '\n'.join([self.random_str() for _ in range(10)])
             bin_res = res.encode('utf-8')
             fid = self.random_str('requirements.txt_fid')
             cluster_id = self.random_str('cluster_id')
+            cluster = ClusterDetails(dict(id=cluster_id, type=const.ClusterType.AWS.value))
 
             _upload.return_value = fid
             _popen.return_value.communicate.return_value = (bin_res, self.random_bytes(10))
+            cluster_fetch_and_validate_by_id.return_value = cluster
 
             res_fid = disco.Job._get_venv_requirements(cluster_id=cluster_id)
 
+            cluster_fetch_and_validate_by_id.assert_called_with(cluster_id)
             assert res_fid == fid
 
             _popen.return_value.communicate.assert_called_once()
@@ -252,12 +256,12 @@ class TestJobs(BaseTest):
                 }
             }
 
-            job = disco.Job.create(input_file_ids=input_file_id, job_name=job_name,
+            job = disco.Job.create(input_file_ids=input_file_id, job_name=job_name, instance_cost=InstanceCost.lowCost.value,
                                    script_repo_id=repository_id, script_file_path_in_repo=file_path,
                                    docker_image_id=docker_image_id)
 
             graphql_mock.assert_called_once_with('createJob', args={'name': job_name, 'inputIds': input_file_id, 'constantIds': [],
-                                                 'clusterId': None, 'clusterInstanceType': 's',
+                                                 'clusterId': None, 'clusterInstanceType': 's', 'instanceCostType': InstanceCost.lowCost.value,
                                                  'dockerImageId': docker_image_id, 'scriptRepoId': repository_id,
                                                  'scriptFilePath': file_path}, options={'executeOnSubmit': False})
             assert job.job_id == expected_job_id
@@ -307,14 +311,14 @@ class TestJobs(BaseTest):
             }
 
             job = disco.Job.create(input_file_ids=input_file_id, job_name=job_name,
-                                   instance_cost='guaranteed',
+                                   instance_cost=InstanceCost.guaranteed.value,
                                    script_repo_id=repository_id, script_file_path_in_repo=file_path)
 
             graphql_mock.assert_called_once_with('createJob', args={'name': job_name,
                                                                     'inputIds': input_file_id, 
                                                                     'constantIds': [],
                                                                     'clusterId': None,
-                                                                    'instanceCostType': 'guaranteed',
+                                                                    'instanceCostType': InstanceCost.guaranteed.value,
                                                                     'clusterInstanceType': 's',
                                                                     'dockerImageId': None,
                                                                     'scriptRepoId': repository_id,
